package it.tref.liferay.mapit.map.hook.listener;

import com.liferay.portal.ModelListenerException;
import com.liferay.portal.kernel.log.Log;
import com.liferay.portal.kernel.log.LogFactoryUtil;
import com.liferay.portal.kernel.util.Validator;
import com.liferay.portal.model.BaseModelListener;
import com.liferay.portlet.expando.model.ExpandoColumn;
import com.liferay.portlet.expando.model.ExpandoValue;
import com.liferay.portlet.expando.service.ExpandoColumnLocalServiceUtil;
import com.liferay.portlet.expando.service.ExpandoValueLocalServiceUtil;

import it.tref.liferay.mapit.constants.Constants;
import it.tref.liferay.mapit.util.MapItUtil;

public class ExpandoValueListener extends BaseModelListener<ExpandoValue> {

  private final static Log _log = LogFactoryUtil.getLog(ExpandoValueListener.class);

  @Override
  public void onBeforeCreate(ExpandoValue model) throws ModelListenerException {

    updateMapItCustomFields(model);
  }

  @Override
  public void onBeforeUpdate(ExpandoValue model) throws ModelListenerException {

    updateMapItCustomFields(model);
  }

  private void updateMapItCustomFields(ExpandoValue model) {

    try {



      ExpandoColumn expandoColumn = model.getColumn();

      if (expandoColumn.getName().equals(Constants.EXPANDO_COLUMN_NAME_LAT)) {
        String value = model.getString();
        ExpandoColumn expandoColumnHidden =
            ExpandoColumnLocalServiceUtil.getColumn(model.getTableId(), Constants.EXPANDO_COLUMN_NAME_LAT_HIDDEN);

        if (Validator.isNull(value)) {
          ExpandoValueLocalServiceUtil.addValue(model.getClassNameId(), model.getTableId(), expandoColumnHidden
              .getColumnId(), model.getClassPK(), value);
        } else {
          String encoded = MapItUtil.encodeLat(value);

          ExpandoValueLocalServiceUtil.addValue(model.getClassNameId(), model.getTableId(), expandoColumnHidden
              .getColumnId(), model.getClassPK(), encoded);

          model.setString(MapItUtil.decodeLat(encoded));
        }
      } else if (expandoColumn.getName().equals(Constants.EXPANDO_COLUMN_NAME_LON)) {
        String value = model.getString();
        ExpandoColumn expandoColumnHidden =
            ExpandoColumnLocalServiceUtil.getColumn(model.getTableId(), Constants.EXPANDO_COLUMN_NAME_LON_HIDDEN);

        if (Validator.isNull(value)) {
          ExpandoValueLocalServiceUtil.addValue(model.getClassNameId(), model.getTableId(), expandoColumnHidden
              .getColumnId(), model.getClassPK(), value);
        } else {
          String encoded = MapItUtil.encodeLon(value);

          ExpandoValueLocalServiceUtil.addValue(model.getClassNameId(), model.getTableId(), expandoColumnHidden
              .getColumnId(), model.getClassPK(), encoded);

          model.setString(MapItUtil.decodeLon(encoded));
        }
      }
    } catch (Exception e) {
      _log.error(e, e);
    }
  }
}
